@@ -42,9 +42,9 @@ if(mode=='local'):
                 s=requests.session()
 
                 payload2 = "https://www.nseindia.com"
-                output2 = requests.get(payload2,headers=headers).json()
+                output2 = s.get(payload2,headers=headers).json()
 
-                output = requests.get(payload,headers=headers).json()
+                output = s.get(payload,headers=headers).json()
         return output
 
 
@@ -828,4 +828,50 @@ def nse_price_band_hitters(bandtype="both",view="AllSec"):
   
   #bandtype can be upper, lower, both
   #view can be AllSec,SecGtr20,SecLwr20
-  return pd.DataFrame(payload[bandtype][view]["data"])
\ No newline at end of file
+  return pd.DataFrame(payload[bandtype][view]["data"])
+
+def nse_largedeals(mode="bulk_deals"):
+  payload = nsefetch('https://www.nseindia.com/api/snapshot-capital-market-largedeal')
+  if(mode=="bulk_deals"):
+    return pd.DataFrame(payload["BULK_DEALS_DATA"])
+  if(mode=="short_deals"):
+    return pd.DataFrame(payload["SHORT_DEALS_DATA"])
+  if(mode=="block_deals"):
+    return pd.DataFrame(payload["BLOCK_DEALS_DATA"])
+  
+def nse_largedeals_historical(from_date, to_date, mode="bulk_deals"):
+    if mode == "bulk_deals":
+        mode = "bulk-deals"
+    elif mode == "short_deals":
+        mode = "short-selling"
+    elif mode == "block_deals":
+        mode = "block-deals"
+    
+    url='https://www.nseindia.com/api/historical/' + mode + '?from=' + from_date + '&to=' + to_date
+    logging.info("Fetching " + str(url))
+    payload = nsefetch(url)
+    return pd.DataFrame(payload["data"])
+
+#https://forum.unofficed.com/t/feature-request-nse-fno-participant-wise-oi/1179/7
+#print(get_fao_participant_oi("04-06-2021"))
+def get_fao_participant_oi(date):
+    date = date.replace("-","")
+    payload=pd.read_csv("https://archives.nseindia.com/content/nsccl/fao_participant_oi_"+date+".csv")
+    return payload
+
+#https://forum.unofficed.com/t/how-to-check-if-the-market-is-open-today-or-not/1268/1
+def is_market_open(segment = "FO"): #COM,CD,CB,CMOT,COM,FO,IRD,MF,NDM,NTRP,SLBS
+    
+    holiday_json = nse_holidays()[segment]
+
+    # Get today's date in the format 'dd-Mon-yyyy'
+    today_date = datetime.date.today().strftime('%d-%b-%Y')
+
+    # Check if today's date is in the holiday_json
+    for holiday in holiday_json:
+        if holiday['tradingDate'] != today_date:
+            print("FNO Market is open today. Have a Nice Trade!")
+            return True
+        if holiday['tradingDate'] == today_date:
+            print(f"Market is closed today because of {holiday['description']}")
+            return False
\ No newline at end of file
